@@ -245,7 +245,6 @@ impl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> EVMImpl<'a, GSPEC, DB,
     fn initialization<SPEC: Spec>(&mut self) -> u64 {
         let is_create = matches!(self.data.env.tx.transact_to, TransactTo::Create(_));
         let input = &self.data.env.tx.data;
-        let access_list = self.data.env.tx.access_list.clone();
 
         if crate::USE_GAS {
             let zero_data_len = input.iter().filter(|v| **v == 0).count() as u64;
@@ -253,17 +252,16 @@ impl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> EVMImpl<'a, GSPEC, DB,
             let (accessed_accounts, accessed_slots) = {
                 if SPEC::enabled(BERLIN) {
                     let mut accessed_slots = 0_u64;
-                    let accessed_accounts = access_list.len() as u64;
 
-                    for (address, slots) in access_list {
+                    for (address, slots) in self.data.env.tx.access_list.iter() {
                         //TODO trace load access_list?
-                        self.data.subroutine.load_account(address, self.data.db);
+                        self.data.subroutine.load_account(*address, self.data.db);
                         accessed_slots += slots.len() as u64;
                         for slot in slots {
-                            self.data.subroutine.sload(address, slot, self.data.db);
+                            self.data.subroutine.sload(*address, *slot, self.data.db);
                         }
                     }
-                    (accessed_accounts, accessed_slots)
+                    (self.data.env.tx.access_list.len() as u64, accessed_slots)
                 } else {
                     (0, 0)
                 }
@@ -383,7 +381,7 @@ impl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> EVMImpl<'a, GSPEC, DB,
 
         if Self::INSPECT {
             self.inspector
-                .initialize_interp(&mut interp, &mut self.data, false); // TODO fix is_static
+                .initialize_interp(&mut interp, &mut self.data, SPEC::IS_STATIC_CALL);
         }
         let exit_reason = interp.run::<Self, SPEC>(self);
 
@@ -482,17 +480,14 @@ impl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> EVMImpl<'a, GSPEC, DB,
         }
 
         // Transfer value from caller to called account
-        match self.data.subroutine.transfer(
+        if let Err(e) = self.data.subroutine.transfer(
             inputs.transfer.source,
             inputs.transfer.target,
             inputs.transfer.value,
             self.data.db,
         ) {
-            Err(e) => {
-                self.data.subroutine.checkpoint_revert(checkpoint);
-                return (e, gas, Bytes::new());
-            }
-            Ok((_source_is_cold, _target_is_cold)) => {}
+            self.data.subroutine.checkpoint_revert(checkpoint);
+            return (e, gas, Bytes::new());
         }
 
         // Call precompiles
@@ -539,8 +534,9 @@ impl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> EVMImpl<'a, GSPEC, DB,
             let mut interp = Interpreter::new::<SPEC>(contract, gas.limit());
 
             if Self::INSPECT {
+                // create is always no static call.
                 self.inspector
-                    .initialize_interp(&mut interp, &mut self.data, false); // TODO fix is_static
+                    .initialize_interp(&mut interp, &mut self.data, false);
             }
             let exit_reason = interp.run::<Self, SPEC>(self);
             if matches!(exit_reason, return_ok!()) {
@@ -618,7 +614,7 @@ impl<'a, GSPEC: Spec, DB: Database + 'a, const INSPECT: bool> Host
     }
 
     fn sload(&mut self, address: H160, index: U256) -> (U256, bool) {
-        // account is allways hot. reference on that statement https://eips.ethereum.org/EIPS/eip-2929 see `Note 2:`
+        // account is always hot. reference on that statement https://eips.ethereum.org/EIPS/eip-2929 see `Note 2:`
         self.data.subroutine.sload(address, index, self.data.db)
     }
 
